<?php
namespace Teknisa\CUS\Modules\Relatorio\Controllers;

use Zeedhi\Framework\Report\ReportService;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DTO\Response\Error;

class Cus09900AnaliseComparativaGerencial extends \Zeedhi\Framework\Controller\Report {

	protected $reportService;
	protected $crudService;
	protected $dataSourceManager;
	protected $novoCodigo;
	protected $entityManager;
	protected $qr2Strategy;
	protected $util;
	protected $birtStrategy;

	public function __construct($reportService, $crudService, $dataSourceManager, $novoCodigo, $entityManager, $qr2Strategy, $util,$birtStrategy) {
		$this->reportService 	= $reportService;
		$this->crudService    	= $crudService;
		$this->dataSourceManager= $dataSourceManager;
		$this->novoCodigo    	= $novoCodigo;
		$this->entityManager    = $entityManager;
		$this->qr2Strategy      = $qr2Strategy;
		$this->util             = $util;
		$this->birtStrategy     = $birtStrategy;
	}

	protected $reportMapping = array (
		'CUS09900' => array (
			'strategy' => 'BIRT',
			'parameterMapping' 		=> array (
		    'CDGRUPFILI'        => 'P_CDGRUPO',
		    'LFILIAL'           => 'L_FILIAL1',
		    'LFILIAL2'          => 'L_FILIAL2',
		    'LFILIAL3'          => 'L_FILIAL3',
		    'LFILIAL4'          => 'L_FILIAL4',
		    'LSERVICO'          => 'L_SERVICO1',
		    'LSERVICO2'         => 'L_SERVICO2',
		    'LSERVICO3'         => 'L_SERVICO3',
		    'LTIPOPRAT'         => 'P_CDTIPOPRAT',
		    'NRCONSPLAN'        => 'P_NRCONSPLAN',
		    'CDTIPOCUSTOPLAN'   => 'P_NRTIPOCUSTO',
		    'CDTIPOCUSTOREAL'   => 'P_NRTIPOCUSTOREAL',
		    'NMTIPOCUSTOPLAN'   => 'P_NMCUSTO',
		    'NMTIPOCUSTOREAL'   => 'P_NMCUSTOREAL',
		    'DTINICIAL'         => 'P_DTINICIAL',
		    'DTFINAL'           => 'P_DTFINAL',
		    'PERINICIAL'        => 'P_PERINICIAL',
		    'PERFINAL'          => 'P_PERFINAL',
		    'CDPRODUTOINI'      => 'P_CDPRODINI',
		    'CDPRODUTOFIN'      => 'P_CDPRODFIM',
		    'DATACALC'          => 'P_DATACALC',
		    'DTCUSTO'           => 'P_DATACUSTO',
		    'CDPICTPROD'        => 'P_CDPICTPROD',
		    'NRTAMACNIVEL'      => 'P_NRTAMACNIVEL',
		    'ORDENA'            => 'P_NRTAMCODIGO',
		    'NRORG'             => 'P_NRORG'
			)
		),
		'CUS09901' => array (
			'strategy' => 'BIRT',
			'parameterMapping' 	=> array (
		    'CDGRUPFILI'        => 'P_CDGRUPO',
		    'LFILIAL'           => 'L_FILIAL1',
		    'LFILIAL2'          => 'L_FILIAL2',
		    'LFILIAL3'          => 'L_FILIAL3',
		    'LTIPOPRAT'         => 'P_CDTIPOPRAT',
		    'NRCONSPLAN'        => 'P_NRCONSPLAN',
		    'CDTIPOCUSTOPLAN'   => 'P_NRTIPOCUSTO',
		    'CDTIPOCUSTOREAL'   => 'P_NRTIPOCUSTOREAL',
		    'NMTIPOCUSTOPLAN'   => 'P_NMCUSTO',
		    'NMTIPOCUSTOREAL'   => 'P_NMCUSTOREAL',
		    'DTINICIAL'         => 'P_DTINICIAL',
		    'DTFINAL'           => 'P_DTFINAL',
		    'PERINICIAL'        => 'P_PERINICIAL',
		    'PERFINAL'          => 'P_PERFINAL',
		    'CDPRODUTOINI'      => 'P_CDPRODINI',
		    'CDPRODUTOFIN'      => 'P_CDPRODFIM',
		    'DATACALC'          => 'P_DATACALC',
		    'NRORG'             => 'P_NRORG',
		    'LSERVICO'          => 'L_SERVICO1',
		    'LSERVICO2'         => 'L_SERVICO2',
		    'LSERVICO3'         => 'L_SERVICO3'
			)
		),
		'CUS09902' => array (
			'strategy' => 'BIRT',
			'parameterMapping' 	=> array (
		    'CDGRUPFILI'        => 'P_CDGRUPO',
		    'LFILIAL'           => 'L_FILIAL1',
		    'LTIPOPRAT'         => 'P_CDTIPOPRAT',
		    'NRCONSPLAN'        => 'P_NRCONSPLAN',
		    'CDTIPOCUSTOPLAN'   => 'P_NRTIPOCUSTO',
		    'NMTIPOCUSTOPLAN'   => 'P_NMCUSTO',
		    'DATACALC'          => 'P_DATACALC',
		    'CDPICTPROD'        => 'P_CDPICTPROD',
		    'CDPICTPRAT'        => 'P_CDPICTPRAT',
		    'NRTAMACNIVEL'      => 'P_NRTAMACNIVEL',
		    'ORDENA'            => 'P_NRTAMCODIGO',
		    'NRORG'             => 'P_NRORG'
			)
		),
		'CUS09903' => array (
			'strategy' => 'BIRT',
			'parameterMapping' 	=> array (
		    'CDGRUPFILI'       => 'P_CDGRUPO',
		    'LFILIAL'          => 'L_FILIAL1',
		    'LFILIAL2'         => 'L_FILIAL2',
		    'LFILIAL3'         => 'L_FILIAL3',
		    'LSERVICO'         => 'L_SERVICO1',
		    'LSERVICO3'        => 'L_SERVICO3',
		    'LTIPOPRAT'        => 'P_CDTIPOPRAT',
		    'NRCONSPLAN'       => 'P_NRCONSPLAN',
		    'CDTIPOCUSTOPLAN'  => 'P_NRTIPOCUSTO',
		    'CDTIPOCUSTOREAL'  => 'P_NRTIPOCUSTOREAL',
		    'NMTIPOCUSTOPLAN'  => 'P_NMCUSTO',
		    'NMTIPOCUSTOREAL'  => 'P_NMCUSTOREAL',
		    'DTINICIAL'        => 'P_DTINICIAL',
		    'DTFINAL'          => 'P_DTFINAL',
		    'CDPRODUTOINI'     => 'P_CDPRODINI',
		    'CDPRODUTOFIN'     => 'P_CDPRODFIM',
		    'DATACALC'         => 'P_DATACALC',
		    'DTCUSTO'          => 'P_DATACUSTO',
		    'NRTAMACNIVEL'     => 'P_NRTAMACNIVEL',
		    'ORDENA'           => 'P_NRTAMCODIGO',
		    'CDPICTPROD'       => 'P_CDPICTPROD',
		    'NRORG'            => 'P_NRORG'
			)
		),
		'CUS09904' => array (
			'strategy' => 'BIRT',
			'parameterMapping' 	=> array (
		    'CDGRUPFILI'       => 'P_CDGRUPO',
		    'LFILIAL'          => 'L_FILIAL1',
		    'LFILIAL2'         => 'L_FILIAL2',
		    'LFILIAL3'         => 'L_FILIAL3',
		    'LFILIAL4'         => 'L_FILIAL4',
		    'LSERVICO'         => 'L_SERVICO1',
		    'LSERVICO2'        => 'L_SERVICO2',
		    'LSERVICO3'        => 'L_SERVICO3',
		    'LTIPOPRAT'        => 'P_CDTIPOPRAT',
		    'NRCONSPLAN'       => 'P_NRCONSPLAN',
		    'CDTIPOCUSTOPLAN'  => 'P_NRTIPOCUSTO',
		    'CDTIPOCUSTOREAL'  => 'P_NRTIPOCUSTOREAL',
		    'NMTIPOCUSTOPLAN'  => 'P_NMCUSTO',
		    'NMTIPOCUSTOREAL'  => 'P_NMCUSTOREAL',
		    'DTINICIAL'        => 'P_DTINICIAL',
		    'DTFINAL'          => 'P_DTFINAL',
		    'PERINICIAL'       => 'P_PERINICIAL',
		    'PERFINAL'         => 'P_PERFINAL',
		    'DTMESINIC'        => 'P_DTMESINIC',
		    'DTMESFINA'        => 'P_DTMESFINA',
		    'CDPRODUTOINI'     => 'P_CDPRODINI',
		    'CDPRODUTOFIN'     => 'P_CDPRODFIM',
		    'IDDTCALC'         => 'P_IDDTCALC',
		    'DATACALC'         => 'P_DATACALC',
		    'DTCUSTO'          => 'P_DATACUSTO',
		    'NRTAMACNIVEL'     => 'P_NRTAMACNIVEL',
		    'ORDENA'           => 'P_NRTAMCODIGO',
		    'CDPICTPROD'       => 'P_CDPICTPROD',
		    'CDPICTPRAT'       => 'P_CDPICTPRAT',
		    'NRORG'            => 'P_NRORG'
			)
		),
		'CUS09905' => array (
			'strategy' => 'BIRT',
			'parameterMapping' 	=> array (
		    'CDGRUPFILI'       => 'P_CDGRUPO',
		    'LFILIAL'          => 'L_FILIAL1',
		    'LFILIAL2'         => 'L_FILIAL2',
		    'LFILIAL3'         => 'L_FILIAL3',
		    'LFILIAL4'         => 'L_FILIAL4',
		    'LSERVICO'         => 'L_SERVICO1',
		    'LSERVICO2'        => 'L_SERVICO2',
		    'LSERVICO3'        => 'L_SERVICO3',
		    'LTIPOPRAT'        => 'P_CDTIPOPRAT',
		    'NRCONSPLAN'       => 'P_NRCONSPLAN',
		    'CDTIPOCUSTOPLAN'  => 'P_NRTIPOCUSTO',
		    'CDTIPOCUSTOREAL'  => 'P_NRTIPOCUSTOREAL',
		    'NMTIPOCUSTOPLAN'  => 'P_NMCUSTO',
		    'NMTIPOCUSTOREAL'  => 'P_NMCUSTOREAL',
		    'DTINICIAL'        => 'P_DTINICIAL',
		    'DTFINAL'          => 'P_DTFINAL',
		    'PERINICIAL'       => 'P_PERINICIAL',
		    'PERFINAL'         => 'P_PERFINAL',
		    'DTMESINIC'        => 'P_DTMESINIC',
		    'DTMESFINA'        => 'P_DTMESFINA',
		    'CDPRODUTOINI'     => 'P_CDPRODINI',
		    'CDPRODUTOFIN'     => 'P_CDPRODFIM',
		    'IDDTCALC'         => 'P_IDDTCALC',
		    'DATACALC'         => 'P_DATACALC',
		    'DTCUSTO'          => 'P_DATACUSTO',
		    'NRTAMACNIVEL'     => 'P_NRTAMACNIVEL',
		    'ORDENA'           => 'P_NRTAMCODIGO',
		    'CDPICTPROD'       => 'P_CDPICTPROD',
		    'NRORG'            => 'P_NRORG'
			)
		),
		'CUS09906' => array (
			'strategy' => 'BIRT',
			'parameterMapping' 	=> array (
		    'CDGRUPFILI'       => 'P_CDGRUPO',
		    'LFILIAL'          => 'L_FILIAL1',
		    'LFILIAL2'         => 'L_FILIAL2',
		    'LFILIAL3'         => 'L_FILIAL3',
		    'LFILIAL4'         => 'L_FILIAL4',
		    'LSERVICO'         => 'L_SERVICO1',
		    'LSERVICO2'        => 'L_SERVICO2',
		    'LSERVICO3'        => 'L_SERVICO3',
		    'LTIPOPRAT'        => 'P_CDTIPOPRAT',
		    'NRCONSPLAN'       => 'P_NRCONSPLAN',
		    'CDTIPOCUSTOPLAN'  => 'P_NRTIPOCUSTO',
		    'CDTIPOCUSTOREAL'  => 'P_NRTIPOCUSTOREAL',
		    'NMTIPOCUSTOPLAN'  => 'P_NMCUSTO',
		    'NMTIPOCUSTOREAL'  => 'P_NMCUSTOREAL',
		    'DTINICIAL'        => 'P_DTINICIAL',
		    'DTFINAL'          => 'P_DTFINAL',
		    'PERINICIAL'       => 'P_PERINICIAL',
		    'PERFINAL'         => 'P_PERFINAL',
		    'DTMESINIC'        => 'P_DTMESINIC',
		    'DTMESFINA'        => 'P_DTMESFINA',
		    'CDPRODUTOINI'     => 'P_CDPRODINI',
		    'CDPRODUTOFIN'     => 'P_CDPRODFIM',
		    'IDDTCALC'         => 'P_IDDTCALC',
		    'DATACALC'         => 'P_DATACALC',
		    'DTCUSTO'          => 'P_DATACUSTO',
		    'NRTAMACNIVEL'     => 'P_NRTAMACNIVEL',
		    'ORDENA'           => 'P_NRTAMCODIGO',
		    'NRORG'            => 'P_NRORG'
			)
		),
		'CUS09907' => array (
			'strategy' => 'BIRT',
			'parameterMapping' 	=> array (
		    'CDGRUPFILI'       => 'P_CDGRUPO',
		    'LFILIAL'          => 'L_FILIAL1',
		    'LFILIAL2'         => 'L_FILIAL2',
		    'LFILIAL3'         => 'L_FILIAL3',
		    'LFILIAL4'         => 'L_FILIAL4',
		    'LSERVICO'         => 'L_SERVICO1',
		    'LSERVICO2'        => 'L_SERVICO2',
		    'LSERVICO3'        => 'L_SERVICO3',
		    'LTIPOPRAT'        => 'P_CDTIPOPRAT',
		    'NRCONSPLAN'       => 'P_NRCONSPLAN',
		    'CDTIPOCUSTOPLAN'  => 'P_NRTIPOCUSTO',
		    'CDTIPOCUSTOREAL'  => 'P_NRTIPOCUSTOREAL',
		    'NMTIPOCUSTOPLAN'  => 'P_NMCUSTO',
		    'NMTIPOCUSTOREAL'  => 'P_NMCUSTOREAL',
		    'DTINICIAL'        => 'P_DTINICIAL',
		    'DTFINAL'          => 'P_DTFINAL',
		    'PERINICIAL'       => 'P_PERINICIAL',
		    'PERFINAL'         => 'P_PERFINAL',
		    'DTMESINIC'        => 'P_DTMESINIC',
		    'DTMESFINA'        => 'P_DTMESFINA',
		    'CDPRODUTOINI'     => 'P_CDPRODINI',
		    'CDPRODUTOFIN'     => 'P_CDPRODFIM',
		    'IDDTCALC'         => 'P_IDDTCALC',
		    'DATACALC'         => 'P_DATACALC',
		    'DTCUSTO'          => 'P_DATACUSTO',
		    'NRTAMACNIVEL'     => 'P_NRTAMACNIVEL',
		    'ORDENA'           => 'P_NRTAMCODIGO',
		    'CDPICTPROD'       => 'P_CDPICTPROD',
		    'CDPICTPRAT'       => 'P_CDPICTPRAT',
		    'NRORG'            => 'P_NRORG'
			)
		),
		'CUS09908' => array (
			'strategy' => 'BIRT',
			'parameterMapping' 	=> array (
		    'CDGRUPFILI'       => 'P_CDGRUPO',
		    'LFILIAL'          => 'L_FILIAL1',
		    'LFILIAL2'         => 'L_FILIAL2',
		    'LFILIAL3'         => 'L_FILIAL3',
		    'LFILIAL4'         => 'L_FILIAL4',
		    'LSERVICO'         => 'L_SERVICO1',
		    'LSERVICO2'        => 'L_SERVICO2',
		    'LSERVICO3'        => 'L_SERVICO3',
		    'LTIPOPRAT'        => 'P_CDTIPOPRAT',
		    'NRCONSPLAN'       => 'P_NRCONSPLAN',
		    'CDTIPOCUSTOPLAN'  => 'P_NRTIPOCUSTO',
		    'CDTIPOCUSTOREAL'  => 'P_NRTIPOCUSTOREAL',
		    'NMTIPOCUSTOPLAN'  => 'P_NMCUSTO',
		    'NMTIPOCUSTOREAL'  => 'P_NMCUSTOREAL',
		    'DTINICIAL'        => 'P_DTINICIAL',
		    'DTFINAL'          => 'P_DTFINAL',
		    'PERINICIAL'       => 'P_PERINICIAL',
		    'PERFINAL'         => 'P_PERFINAL',
		    'DTMESINIC'        => 'P_DTMESINIC',
		    'DTMESFINA'        => 'P_DTMESFINA',
		    'CDPRODUTOINI'     => 'P_CDPRODINI',
		    'CDPRODUTOFIN'     => 'P_CDPRODFIM',
		    'IDDTCALC'         => 'P_IDDTCALC',
		    'DATACALC'         => 'P_DATACALC',
		    'DTCUSTO'          => 'P_DATACUSTO',
		    'NRTAMACNIVEL'     => 'P_NRTAMACNIVEL',
		    'ORDENA'           => 'P_NRTAMCODIGO',
		    'CDPICTPROD'       => 'P_CDPICTPROD',
		    'CDPICTPRAT'       => 'P_CDPICTPRAT',
		    'NRORG'            => 'P_NRORG'
			)
		),
		'CUS09909' => array (
			'strategy' => 'BIRT',
			'parameterMapping' 	=> array (
		    'CDGRUPFILI'       => 'P_CDGRUPO',
		    'LFILIAL'          => 'L_FILIAL1',
		    'LFILIAL2'         => 'L_FILIAL2',
		    'LFILIAL3'         => 'L_FILIAL3',
		    'LFILIAL4'         => 'L_FILIAL4',
		    'LSERVICO'         => 'L_SERVICO1',
		    'LSERVICO2'        => 'L_SERVICO2',
		    'LSERVICO3'        => 'L_SERVICO3',
		    'LTIPOPRAT'        => 'P_CDTIPOPRAT',
		    'NRCONSPLAN'       => 'P_NRCONSPLAN',
		    'CDTIPOCUSTOPLAN'  => 'P_NRTIPOCUSTO',
		    'CDTIPOCUSTOREAL'  => 'P_NRTIPOCUSTOREAL',
		    'NMTIPOCUSTOPLAN'  => 'P_NMCUSTO',
		    'NMTIPOCUSTOREAL'  => 'P_NMCUSTOREAL',
		    'DTINICIAL'        => 'P_DTINICIAL',
		    'DTFINAL'          => 'P_DTFINAL',
		    'PERINICIAL'       => 'P_PERINICIAL',
		    'PERFINAL'         => 'P_PERFINAL',
		    'DTMESINIC'        => 'P_DTMESINIC',
		    'DTMESFINA'        => 'P_DTMESFINA',
		    'CDPRODUTOINI'     => 'P_CDPRODINI',
		    'CDPRODUTOFIN'     => 'P_CDPRODFIM',
		    'IDDTCALC'         => 'P_IDDTCALC',
		    'DATACALC'         => 'P_DATACALC',
		    'DTCUSTO'          => 'P_DATACUSTO',
		    'NRTAMACNIVEL'     => 'P_NRTAMACNIVEL',
		    'ORDENA'           => 'P_NRTAMCODIGO',
		    'CDPICTPROD'       => 'P_CDPICTPROD',
		    'NRORG'            => 'P_NRORG'
			)
		),
		'CUS0990A' => array (
			'strategy' => 'BIRT',
			'parameterMapping' 	=> array (
		    'CDGRUPFILI'       => 'P_CDGRUPO',
		    'LFILIAL'          => 'L_FILIAL1',
		    'LFILIAL2'         => 'L_FILIAL2',
		    'LFILIAL3'         => 'L_FILIAL3',
		    'LFILIAL4'         => 'L_FILIAL4',
		    'LSERVICO'         => 'L_SERVICO1',
		    'LSERVICO2'        => 'L_SERVICO2',
		    'LSERVICO3'        => 'L_SERVICO3',
		    'LTIPOPRAT'        => 'P_CDTIPOPRAT',
		    'NRCONSPLAN'       => 'P_NRCONSPLAN',
		    'CDTIPOCUSTOPLAN'  => 'P_NRTIPOCUSTO',
		    'CDTIPOCUSTOREAL'  => 'P_NRTIPOCUSTOREAL',
		    'NMTIPOCUSTOPLAN'  => 'P_NMCUSTO',
		    'NMTIPOCUSTOREAL'  => 'P_NMCUSTOREAL',
		    'DTINICIAL'        => 'P_DTINICIAL',
		    'DTFINAL'          => 'P_DTFINAL',
		    'PERINICIAL'       => 'P_PERINICIAL',
		    'PERFINAL'         => 'P_PERFINAL',
		    'DTMESINIC'        => 'P_DTMESINIC',
		    'DTMESFINA'        => 'P_DTMESFINA',
		    'CDPRODUTOINI'     => 'P_CDPRODINI',
		    'CDPRODUTOFIN'     => 'P_CDPRODFIM',
		    'IDDTCALC'         => 'P_IDDTCALC',
		    'DATACALC'         => 'P_DATACALC',
		    'DTCUSTO'          => 'P_DATACUSTO',
		    'NRTAMACNIVEL'     => 'P_NRTAMACNIVEL',
		    'ORDENA'           => 'P_NRTAMCODIGO',
		    'CDPICTPROD'       => 'P_CDPICTPROD',
		    'NRORG'            => 'P_NRORG'
			)
		),
		'CUS0990B' => array (
			'strategy' => 'BIRT',
			'parameterMapping' 	=> array (
		    'CDGRUPFILI'       => 'P_CDGRUPO',
		    'LFILIAL'          => 'L_FILIAL1',
		    'LFILIAL2'         => 'L_FILIAL2',
		    'LFILIAL3'         => 'L_FILIAL3',
		    'LFILIAL4'         => 'L_FILIAL4',
		    'LSERVICO'         => 'L_SERVICO1',
		    'LSERVICO2'        => 'L_SERVICO2',
		    'LSERVICO3'        => 'L_SERVICO3',
		    'LTIPOPRAT'        => 'P_CDTIPOPRAT',
		    'NRCONSPLAN'       => 'P_NRCONSPLAN',
		    'CDTIPOCUSTOPLAN'  => 'P_NRTIPOCUSTO',
		    'CDTIPOCUSTOREAL'  => 'P_NRTIPOCUSTOREAL',
		    'NMTIPOCUSTOPLAN'  => 'P_NMCUSTO',
		    'NMTIPOCUSTOREAL'  => 'P_NMCUSTOREAL',
		    'DTINICIAL'        => 'P_DTINICIAL',
		    'DTFINAL'          => 'P_DTFINAL',
		    'PERINICIAL'       => 'P_PERINICIAL',
		    'PERFINAL'         => 'P_PERFINAL',
		    'DTMESINIC'        => 'P_DTMESINIC',
		    'DTMESFINA'        => 'P_DTMESFINA',
		    'CDPRODUTOINI'     => 'P_CDPRODINI',
		    'CDPRODUTOFIN'     => 'P_CDPRODFIM',
		    'IDDTCALC'         => 'P_IDDTCALC',
		    'DATACALC'         => 'P_DATACALC',
		    'DTCUSTO'          => 'P_DATACUSTO',
		    'NRTAMACNIVEL'     => 'P_NRTAMACNIVEL',
		    'ORDENA'           => 'P_NRTAMCODIGO',
		    'CDPICTPROD'       => 'P_CDPICTPROD',
		    'NRORG'            => 'P_NRORG'
			)
		),
		'CUS0990C' => array (
			'strategy' => 'BIRT',
			'parameterMapping' 	=> array (
		    'CDGRUPFILI'       => 'P_CDGRUPO',
		    'LFILIAL'          => 'L_FILIAL1',
		    'LFILIAL2'         => 'L_FILIAL2',
		    'LFILIAL3'         => 'L_FILIAL3',
		    'LFILIAL4'         => 'L_FILIAL4',
		    'LSERVICO'         => 'L_SERVICO1',
		    'LSERVICO2'        => 'L_SERVICO2',
		    'LSERVICO3'        => 'L_SERVICO3',
		    'LTIPOPRAT'        => 'P_CDTIPOPRAT',
		    'NRCONSPLAN'       => 'P_NRCONSPLAN',
		    'CDTIPOCUSTOPLAN'  => 'P_NRTIPOCUSTO',
		    'CDTIPOCUSTOREAL'  => 'P_NRTIPOCUSTOREAL',
		    'NMTIPOCUSTOPLAN'  => 'P_NMCUSTO',
		    'NMTIPOCUSTOREAL'  => 'P_NMCUSTOREAL',
		    'DTINICIAL'        => 'P_DTINICIAL',
		    'DTFINAL'          => 'P_DTFINAL',
		    'PERINICIAL'       => 'P_PERINICIAL',
		    'PERFINAL'         => 'P_PERFINAL',
		    'DTMESINIC'        => 'P_DTMESINIC',
		    'DTMESFINA'        => 'P_DTMESFINA',
		    'CDPRODUTOINI'     => 'P_CDPRODINI',
		    'CDPRODUTOFIN'     => 'P_CDPRODFIM',
		    'IDDTCALC'         => 'P_IDDTCALC',
		    'DATACALC'         => 'P_DATACALC',
		    'DTCUSTO'          => 'P_DATACUSTO',
		    'NRTAMACNIVEL'     => 'P_NRTAMACNIVEL',
		    'ORDENA'           => 'P_NRTAMCODIGO',
		    'CDPICTPROD'       => 'P_CDPICTPROD',
		    'NRORG'            => 'P_NRORG'
			)
		),
		'GRS01517' => array (
			'strategy' => 'BIRT',
			'parameterMapping' 	=> array (
		    'CDGRUPFILI'       => 'P_CDGRUPO',
		    'LFILIAL'          => 'L_FILIAL1',
		    'LFILIAL2'         => 'L_FILIAL2',
		    'LFILIAL3'         => 'L_FILIAL3',
		    'LSERVICO'         => 'L_SERVICO1',
		    'LSERVICO3'        => 'L_SERVICO3',
		    'LTIPOPRAT'        => 'P_CDTIPOPRAT',
		    'NRCONSPLAN'       => 'P_NRCONSPLAN',
		    'CDTIPOCUSTOPLAN'  => 'P_NRTIPOCUSTO',
		    'CDTIPOCUSTOREAL'  => 'P_NRTIPOCUSTOREAL',
		    'NMTIPOCUSTOPLAN'  => 'P_NMCUSTO',
		    'NMTIPOCUSTOREAL'  => 'P_NMCUSTOREAL',
		    'DTINICIAL'        => 'P_DTINICIAL',
		    'DTFINAL'          => 'P_DTFINAL',
		    'CDPRODUTOINI'     => 'P_CDPRODINI',
		    'CDPRODUTOFIN'     => 'P_CDPRODFIM',
		    'DATACALC'         => 'P_DATACALC',
		    'DTCUSTO'          => 'P_DATACUSTO',
		    'NRTAMACNIVEL'     => 'P_NRTAMACNIVEL',
		    'ORDENA'           => 'P_NRTAMCODIGO',
		    'CDPICTPROD'       => 'P_CDPICTPROD',
		    'NRORG'            => 'P_NRORG'
			)
		),
		'GRS01512' => array (
			'strategy' => 'BIRT',
			'parameterMapping' 	=> array (
		    'CDGRUPFILI'       => 'P_CDGRUPO',
		    'LFILIAL'          => 'L_FILIAL1',
		    'LFILIAL2'         => 'L_FILIAL2',
		    'LFILIAL3'         => 'L_FILIAL3',
		    'LFILIAL4'         => 'L_FILIAL4',
		    'LSERVICO'         => 'L_SERVICO1',
		    'LSERVICO2'        => 'L_SERVICO2',
		    'LSERVICO3'        => 'L_SERVICO3',
		    'LTIPOPRAT'        => 'P_CDTIPOPRAT',
		    'NRCONSPLAN'       => 'P_NRCONSPLAN',
		    'CDTIPOCUSTOPLAN'  => 'P_NRTIPOCUSTO',
		    'CDTIPOCUSTOREAL'  => 'P_NRTIPOCUSTOREAL',
		    'NMTIPOCUSTOPLAN'  => 'P_NMCUSTO',
		    'NMTIPOCUSTOREAL'  => 'P_NMCUSTOREAL',
		    'DTINICIAL'        => 'P_DTINICIAL',
		    'DTFINAL'          => 'P_DTFINAL',
		    'PERINICIAL'       => 'P_PERINICIAL',
		    'PERFINAL'         => 'P_PERFINAL',
		    'DTMESINIC'        => 'P_DTMESINIC',
		    'DTMESFINA'        => 'P_DTMESFINA',
		    'CDPRODUTOINI'     => 'P_CDPRODINI',
		    'CDPRODUTOFIN'     => 'P_CDPRODFIM',
		    'IDDTCALC'         => 'P_IDDTCALC',
		    'DATACALC'         => 'P_DATACALC',
		    'DTCUSTO'          => 'P_DATACUSTO',
		    'NRTAMACNIVEL'     => 'P_NRTAMACNIVEL',
		    'ORDENA'           => 'P_NRTAMCODIGO',
		    'CDPICTPROD'       => 'P_CDPICTPROD',
		    'CDPICTPRAT'       => 'P_CDPICTPRAT',
		    'NRORG'            => 'P_NRORG'
			)
		),
		'CUS09915' => array (
			'strategy' => 'BIRT',
			'parameterMapping' 		=> array (
		    'CDGRUPFILI'        => 'P_CDGRUPO',
		    'LFILIAL'           => 'L_FILIAL1',
		    'LFILIAL2'          => 'L_FILIAL2',
		    'LFILIAL3'          => 'L_FILIAL3',
		    'LFILIAL4'          => 'L_FILIAL4',
		    'LSERVICO'          => 'L_SERVICO1',
		    'LSERVICO2'         => 'L_SERVICO2',
		    'LSERVICO3'         => 'L_SERVICO3',
		    'LTIPOPRAT'         => 'P_CDTIPOPRAT',
		    'NRCONSPLAN'        => 'P_NRCONSPLAN',
		    'CDTIPOCUSTOPLAN'   => 'P_NRTIPOCUSTO',
		    'CDTIPOCUSTOREAL'   => 'P_NRTIPOCUSTOREAL',
		    'NMTIPOCUSTOPLAN'   => 'P_NMCUSTO',
		    'NMTIPOCUSTOREAL'   => 'P_NMCUSTOREAL',
		    'DTINICIAL'         => 'P_DTINICIAL',
		    'DTFINAL'           => 'P_DTFINAL',
		    'PERINICIAL'        => 'P_PERINICIAL',
		    'PERFINAL'          => 'P_PERFINAL',
		    'CDPRODUTOINI'      => 'P_CDPRODINI',
		    'CDPRODUTOFIN'      => 'P_CDPRODFIM',
		    'DATACALC'          => 'P_DATACALC',
		    'DTCUSTO'           => 'P_DATACUSTO',
		    'CDPICTPROD'        => 'P_CDPICTPROD',
		    'NRTAMACNIVEL'      => 'P_NRTAMACNIVEL',
		    'ORDENA'            => 'P_NRTAMCODIGO',
		    'NRORG'             => 'P_NRORG'
			)
		),
		'CUS09916' => array (
			'strategy' => 'BIRT',
			'parameterMapping' 	=> array (
		    'CDGRUPFILI'        => 'P_CDGRUPO',
		    'LFILIAL'           => 'L_FILIAL1',
		    'LFILIAL2'          => 'L_FILIAL2',
		    'LFILIAL3'          => 'L_FILIAL3',
		    'LFILIAL4'          => 'L_FILIAL4',
		    'LSERVICO'          => 'L_SERVICO1',
		    'LSERVICO2'         => 'L_SERVICO2',
		    'LSERVICO3'         => 'L_SERVICO3',
		    'LTIPOPRAT'         => 'P_CDTIPOPRAT',
		    'NRCONSPLAN'        => 'P_NRCONSPLAN',
		    'CDTIPOCUSTOPLAN'   => 'P_NRTIPOCUSTO',
		    'CDTIPOCUSTOREAL'   => 'P_NRTIPOCUSTOREAL',
		    'NMTIPOCUSTOPLAN'   => 'P_NMCUSTO',
		    'NMTIPOCUSTOREAL'   => 'P_NMCUSTOREAL',
		    'DTINICIAL'         => 'P_DTINICIAL',
		    'DTFINAL'           => 'P_DTFINAL',
		    'PERINICIAL'        => 'P_PERINICIAL',
		    'PERFINAL'          => 'P_PERFINAL',
		    'CDPRODUTOINI'      => 'P_CDPRODINI',
		    'CDPRODUTOFIN'      => 'P_CDPRODFIM',
		    'DATACALC'          => 'P_DATACALC',
		    'DTCUSTO'           => 'P_DATACUSTO',
		    'CDPICTPROD'        => 'P_CDPICTPROD',
		    'NRTAMACNIVEL'      => 'P_NRTAMACNIVEL',
		    'ORDENA'            => 'P_NRTAMCODIGO',
		    'NRORG'             => 'P_NRORG'
			)
		),
		'CUS09919' => array (
			'strategy' => 'BIRT',
			'parameterMapping' 		=> array (
		    'CDGRUPFILI'        => 'P_CDGRUPO',
		    'LFILIAL'           => 'L_FILIAL1',
		    'LFILIAL2'          => 'L_FILIAL2',
		    'LFILIAL3'          => 'L_FILIAL3',
		    'LFILIAL4'          => 'L_FILIAL4',
		    'LSERVICO'          => 'L_SERVICO1',
		    'LSERVICO2'         => 'L_SERVICO2',
		    'LSERVICO3'         => 'L_SERVICO3',
		    'LTIPOPRAT'         => 'P_CDTIPOPRAT',
		    'NRCONSPLAN'        => 'P_NRCONSPLAN',
		    'CDTIPOCUSTOPLAN'   => 'P_NRTIPOCUSTO',
		    'CDTIPOCUSTOREAL'   => 'P_NRTIPOCUSTOREAL',
		    'NMTIPOCUSTOPLAN'   => 'P_NMCUSTO',
		    'NMTIPOCUSTOREAL'   => 'P_NMCUSTOREAL',
		    'DTINICIAL'         => 'P_DTINICIAL',
		    'DTFINAL'           => 'P_DTFINAL',
		    'PERINICIAL'        => 'P_PERINICIAL',
		    'PERFINAL'          => 'P_PERFINAL',
		    'CDPRODUTOINI'      => 'P_CDPRODINI',
		    'CDPRODUTOFIN'      => 'P_CDPRODFIM',
		    'DATACALC'          => 'P_DATACALC',
		    'DTCUSTO'           => 'P_DATACUSTO',
		    'CDPICTPROD'        => 'P_CDPICTPROD',
		    'NRTAMACNIVEL'      => 'P_NRTAMACNIVEL',
		    'ORDENA'            => 'P_NRTAMCODIGO',
		    'NRORG'             => 'P_NRORG'
			)
		)	
	);

	public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response) {
		$nrorg = $this->crudService->getEnvironment()->getNrOrg();
		$nrlista = $this->novoCodigo->getCodeByTableName('LISTA', $nrorg);
		$nrlistaFilial = $this->novoCodigo->getCodeByTableName('LISTA', $nrorg);
		$nrlistaFiliServ = $this->novoCodigo->getCodeByTableName('LISTA', $nrorg);
		$nrconsplanth = $this->novoCodigo->getCodeByTableName('CONSPLAN'.$this->crudService->getEnvironment()->getCdFilial(), $nrorg);
		$row = $request->getRow();
		 $this->birtStrategy->setReportFormat(strtolower($row['QR2TYPE']));
		$row['CDPRODUTOINI'] = $row['CDARVPRODINI'];
		$row['CDPRODUTOFIN'] = str_pad($row['CDARVPRODFIN'], 10, 'z');
		
		$listaFiliais = $row['LFILIAL'] == 'T' ? $this->getFiliais($row) : $row['NMFILIAL'];
	//	$listaFiliais = join("_", $listaFiliais);
		$row['LFILIALQR2'] = $row['LFILIAL'];
		$row['LSERVICOQR2'] = $row['LSERVICO'];
		if($row['LFILIALQR2'] == 'T'){
			$row['LFILIALQR2'] = implode('_', $listaFiliais);
		}
		$row['LFILIALQR2'] = '_' . $row['LFILIALQR2'] . '_';
		if($row['LSERVICOQR2'] != 'T')
			$row['LSERVICOQR2'] = '_' . $row['LSERVICOQR2'] . '_';
		
		$row['LFILIALQR2_2'] = $row['LFILIALQR2'];
		$row['LFILIALQR2_3'] = $row['LFILIALQR2'];
		$row['LFILIALQR2_4'] = $row['LFILIALQR2'];
		$row['LSERVICOQR2_2'] = $row['LSERVICOQR2'];
		$row['LSERVICOQR2_3'] = $row['LSERVICOQR2'];
		
		$filiserv = $row['LSERVICO'] == 'T' ? $this->getFiliServ($row) : explode('_', $row['LSERVICO']);
		$this->insereLista($nrlistaFilial, $listaFiliais);
		$this->insereLista($nrlista, $filiserv);
		$this->insereLista($nrlistaFiliServ, $filiserv);
		$row['LFILIAL']  = $nrlistaFilial;
		$row['LFILIAL2'] = $nrlistaFilial;
		$row['LFILIAL3'] = $nrlistaFilial;
		$row['LFILIAL4'] = $nrlistaFilial;
		
		$row['LSERVICO'] = $nrlistaFiliServ;
		$row['LSERVICO2'] = $nrlistaFiliServ;
		$row['LSERVICO3'] = $nrlistaFiliServ;
		$row['CDTIPOCUSTOPLAN'] = isset($row['CDTIPOCUSTOPLAN']) ? $row['CDTIPOCUSTOPLAN'] : '';	
		$row['CDTIPOCUSTOREAL'] = isset($row['CDTIPOCUSTOREAL']) ? $row['CDTIPOCUSTOREAL'] : '';
		$row['CDGRUPFILI'] = $row['CDGRUPFILI'] == '' ? 'T' : $row['CDGRUPFILI'];
	
		$row['NRTAMACNIVEL_2'] = $row['NRTAMACNIVEL'];
		$resultado = $this->proceduteConsplanGeral($nrlista, $nrconsplanth, $row, $response);
		$row['NRCONSPLAN'] = null;
		if(isset($resultado)){ 
			if(isset($resultado['NRCONSPLAN'])){
				$row['NRCONSPLAN'] = $resultado['NRCONSPLAN'];
			}
		}
		
		$this->mapearRelGRS($row);
	}

	private function getFiliServ($row) {
		$filiais = $row['LFILIAL'] == 'T' ? $this->getFiliais($row) : $row['NMFILIAL'];
		$filiserv = array();
		foreach ($filiais as $cdfilial) {
			$conditions = array(
				array(
            	    'columnName' => "CDFILIAL",
            	    'operator' => '=',
            	    'value' => $cdfilial
            	),
            	array(
            	    'columnName' => "NRORG",
            	    'operator' => '=',
            	    'value' => $this->crudService->getEnvironment()->getNrOrg()
            	)
            );
			$servicos = $this->crudService->getFilteredDataSet('servico',$conditions)->getRows();
			foreach ($servicos as $servico) {
				array_push($filiserv, $cdfilial.$servico['CDSERVFILI']);
			}
		}
		return $filiserv;
	}
	
	private function getFiliais($row) {
		$filiais = array();
		$conditions = array(
			array(
        	    'columnName' => "CDGRUPFILI",
        	    'operator' => '=',
        	    'value' => $row['CDGRUPFILI'] == '' ? 'T' : $row['CDGRUPFILI']
        	),
        	array(
        	    'columnName' => "CDOPERADOR",
        	    'operator' => '=',
        	    'value' => $this->crudService->getEnvironment()->getCdOperador()
        	),
        	array(
        	    'columnName' => "NRORG",
        	    'operator' => '=',
        	    'value' => $this->crudService->getEnvironment()->getNrOrg()
        	)
        );
        $filterCriteria = new FilterCriteria('filial_operador_grupfili_no_grupfili', $conditions);
		$filterCriteria = $this->crudService->populateParameterBag($filterCriteria, array("CDGRUPFILI", "CDOPERADOR", "NRORG"));
		$dataSetFiliais = $this->dataSourceManager->findBy($filterCriteria)->getRows();
		foreach ($dataSetFiliais as $filial) {
			array_push($filiais, $filial['CDFILIAL']);
		}
		return $filiais;
	}
	
	private function insereLista($nrlista, $filiserv) {
		$rows = array();
		foreach($filiserv as $filialservico){
			array_push($rows,
				array(
					"NRLISTA" 	=> $nrlista,
					"CDLISTA" 	=> $filialservico,
					"__is_new"  => true
				)
			);
		}
		$dataSet = new DataSet(null, $rows);
		$request = new DTO\Request\DataSet($dataSet, '', '', '');
		$rowsToSave = $this->crudService->getRowsToSave($request, 'lista');
		$this->crudService->save('lista', $rowsToSave);
	}
	
	private function proceduteConsplanGeral($nrlista, $nrconsplanth, $row, $response) {
		try {
			$procedure = new StoredProcedure($this->entityManager->getConnection(), 'CONSPLAN_GERAL');
            $procedure->addParam(new Param('NRLISTA', Param::PARAM_INPUT, $nrlista, Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('DTINICIAL', Param::PARAM_INPUT, $row['DTINICIAL'], Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('DTFINAL', Param::PARAM_INPUT, $row['DTFINAL'], Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('IDPRODUTOS', Param::PARAM_INPUT, 'CFP', Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('IDSEPPRATO', Param::PARAM_INPUT, 'P', Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('PEACRESCIMO', Param::PARAM_INPUT, 0, Param::PARAM_TYPE_INT));
            $procedure->addParam(new Param('IDARREDOND', Param::PARAM_INPUT, 'N', Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('CDPRODUTOINI', Param::PARAM_INPUT, $row['CDPRODUTOINI'], Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('CDPRODUTOFIN', Param::PARAM_INPUT, $row['CDPRODUTOFIN'], Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('CDOPERADOR', Param::PARAM_INPUT, $this->crudService->getEnvironment()->getCdOperador(), Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('NRCONSPLANTH', Param::PARAM_INPUT, 'GERANOVCOD', Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('NRCONSPLAN', Param::PARAM_OUTPUT, null, Param::PARAM_TYPE_STR, 10));
            return $procedure->execute();
		} catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
    	}
	}
	
	public function afterProcessReport(DTO\Request\Row $request, DTO\Response $response, $report) {
  		$row = $request->getRow();
		//$this->util->deleteConsplan($row['NRCONSPLAN']);
	}
	
	/*Caso seja o cliente GRSA, cria mapeamento para estes relatórios específicos*/
	private function mapearRelGRS(&$row){
		$codigo = $row['REPORT_NAME'];
		if (strpos(strtoupper($codigo), 'GRS') === false || strpos(strtoupper($codigo), 'GRS') != 0)
			return;
		//Relatórios GRS com mapeamento específico não passam pelo mapeamento QR2
		if ($codigo === 'GRS01517' or $codigo === 'GRS01512')
			return;
		$codigo = $row['REPORT_NAME'];
		$parametros = array();
		//Relatorios GRS convertidos para BIRT que usam o mesmo mapeamento do QR2
		if($codigo === 'GRS01511') {
			$parametros['strategy'] = 'BIRT';
		}
		else {
			$this->qr2Strategy->setQr2Type($row['QR2TYPE']);
			$parametros['strategy'] = 'QR2';
		}
		$mapa = array();
		$mapa['NRORG'] = 'P_NRORG';
		$mapa['CDGRUPFILI'] = 'P_CDGRUPO';
		//Relatorios GRS convertidos para BIRT que usam o mesmo mapeamento do QR2
		if($codigo === 'GRS01511') {
			$mapa['LFILIAL'] = 'L_FILIAL1';
			$mapa['LFILIAL2'] = 'L_FILIAL2';
			$mapa['LFILIAL3'] = 'L_FILIAL3';
			$mapa['LFILIAL4'] = 'L_FILIAL4';
			$mapa['LSERVICO'] = 'L_SERVICO1';
			$mapa['LSERVICO2'] = 'L_SERVICO2';
			$mapa['LSERVICO3'] = 'L_SERVICO3';
		}
		else {
			$mapa['LFILIALQR2'] = 'L_FILIAL1';
			$mapa['LFILIALQR2_2'] = 'L_FILIAL2';
			$mapa['LFILIALQR2_3'] = 'L_FILIAL3';
			$mapa['LFILIALQR2_4'] = 'L_FILIAL4';
			$mapa['LSERVICOQR2'] = 'L_SERVICO1';
			$mapa['LSERVICOQR2_2'] = 'L_SERVICO2';
			$mapa['LSERVICOQR2_3'] = 'L_SERVICO3';	
		}
		$mapa['LTIPOPRAT'] = 'P_CDTIPOPRAT';
		$mapa['NRCONSPLAN'] = 'P_NRCONSPLAN';
		$mapa['CDTIPOCUSTOPLAN'] = 'P_NRTIPOCUSTO';
		$mapa['CDTIPOCUSTOREAL'] = 'P_NRTIPOCUSTOREAL';
		$mapa['NMTIPOCUSTOPLAN'] = 'P_NMCUSTO';
		$mapa['NMTIPOCUSTOREAL'] = 'P_NMCUSTOREAL';
		$mapa['DTINICIAL'] = 'P_DTINICIAL';
		$mapa['DTFINAL'] = 'P_DTFINAL';
		$mapa['PERINICIAL'] = 'P_PERINICIAL';
		$mapa['PERFINAL'] = 'P_PERFINAL';
		$mapa['DTMESINIC'] = 'P_DTMESINIC';
		$mapa['DTMESFINA'] = 'P_DTMESFINA';
		$mapa['CDPRODUTOINI'] = 'P_CDPRODINI';
		$mapa['CDPRODUTOFIN'] = 'P_CDPRODFIM';
		$mapa['NRTAMACNIVEL'] = 'P_NRTAMACNIVEL';
		$mapa['ORDENA'] = 'P_NRTAMCODIGO';
		$mapa['IDDTCALC'] = 'P_IDDTCALC';
		$mapa['DATACALC'] = 'P_DATACALC';
		$mapa['DTCUSTO'] = 'P_DATACUSTO';
		$mapa['NRTAMACNIVEL_2'] = 'P_NRTAMNIVEL';
		$parametros['parameterMapping'] = $mapa;
		$this->reportMapping[$codigo] = $parametros;
	}
}